#!/bin/bash

echo "_____ENVIRONMENT_________________________"
env
echo "_____END ENVIRONMENT_____________________"

build_config="${PWD}/${DISTRO}-build.sh"
fail() { [ $# -eq 0 ] || echo "$@"; exit 1; }

# Get the serial number
"${kvm_scripts}/get_serial.sh" "${DISTRO}" "${WORKSPACE}" "${BUILD_ID}" \
         "${BTYPE}" "${TEST_BUILD}" "${SANDBOX_BUILD}" "${PUBLISH_IMAGE}"

read SERIAL < serial.txt
[ -z ${SERIAL} ] && echo "NO SERIAL" && exit 10

# Create the configurations
"${kvm_scripts}/builder_config.sh" \
     --distro "${DISTRO}" \
     --build-type "${BTYPE}" \
     --arch "${ARCH_TYPE}" \
     --template kvm/img-build.tmpl \
     --serial "${SERIAL}" \
     --bzr-automated-builds "${BZR_AUTOMATED_EC2_BUILDS}" \
     --bzr-pubscripts "${BZR_EC2_PUBSCRIPTS}" \
     --bzr-livebuild "${BZR_LIVEBUILD}" \
     --bzr-vmbuilder "${BZR_VMBUILDER}" \
     --out "${build_config}" ||
        fail "Failed to configure instance configuration"

# Exit after configuring for arm if so configured
if [[ "${ARCH_TYPE}" =~ "arm" ]]; then
   echo "This is an ARM build. ARM rules will apply"
   [ "${BUILD_ARM}" -eq 0 ] && exit 0
fi

# Launch the builder
"${kvm_scripts}/launch_kvm.sh" \
     --id "${BUILD_ID}" \
     --user-data "${build_config}" \
     --cloud-config kvm/cloud-precise.cfg \
     --img-url "${BUILDER_CLOUD_IMAGE}" \
     --raw-disk "${WORKSPACE}/${DISTRO}.raw" \
     --raw-size 20 ||
        fail "KVM instance failed"

tar -xvvf "${WORKSPACE}/${DISTRO}.raw" ||
    fail "Result tar failed to unpack"

rm "${WORKSPACE}/${DISTRO}.raw"

"${kvm_scripts}/copy_to_final.sh" \
     "${DISTRO}" "${WORKSPACE}" "${SERIAL}" "${BTYPE}" "${TEST_BUILD}" "${SANDBOX_BUILD}" ||
    fail "Failed to place final files to destination"

find . -iname "build_properties" | xargs -I FILE cp FILE /var/lib/jenkins/jobs/CloudImage_CustomBuilder/workspace/build_properties ||
    fail "Unable to find build_properties file. Aborting"

echo "PUBLISH_IMAGE=${PUBLISH_IMAGE}" >> /var/lib/jenkins/jobs/CloudImage_CustomBuilder/workspace/build_properties

cat /var/lib/jenkins/jobs/CloudImage_CustomBuilder/workspace/build_properties ||
    fail "Build properties file was not found."
