#!/bin/bash
BUILDER_CLOUD_IMAGE="http://cloud-images.ubuntu.com/releases/precise/release/ubuntu-12.04-server-cloudimg-amd64-disk1.img"
build_config="${PWD}/${DISTRO}-build.sh"

# Read in the common functions
source "${kvm_scripts}/functions/common"
source "${kvm_scripts}/functions/retry"

# Get the serial number
retry 3 10 \
    "${kvm_scripts}/get_serial.sh" \
         "${DISTRO}" "${WORKSPACE}" "${BUILD_ID}" "${BTYPE}" 0 0 1 1 ||
         fail "Failed to get serial for this build"

# Get the serial number
read SERIAL < serial.txt
[ -z ${SERIAL} ] && echo "NO SERIAL" && exit 10

# Create the configurations
"${kvm_scripts}/builder_config.sh" \
     --distro "${DISTRO}" \
     --build-type "${BTYPE}" \
     --arch "${ARCH_TYPE}" \
     --template kvm/img-build.tmpl \
     --serial "${SERIAL}" \
     --out "${build_config}" ||
        fail "Failed to configure instance configuration"

# Exit after configuring for arm if so configured
if [[ "${ARCH_TYPE}" =~ "arm" ]]; then
   echo "This is an ARM build. ARM rules will apply"
   [ "${BUILD_ARM}" -eq 0 ] && exit 0
fi

# Launch the builder
# Retry building the image twice, waiting five
# minutes. This should buffer most failures caused
# by bad mirrors.
retry 2 300 \
    "${kvm_scripts}/launch_kvm.sh" \
         --id "${BUILD_ID}" \
         --user-data "${build_config}" \
         --cloud-config kvm/cloud-precise.cfg \
         --img-url "${BUILDER_CLOUD_IMAGE}" \
         --raw-disk "${WORKSPACE}/${DISTRO}.raw" \
         --raw-size 20 ||
         fail "KVM instance failed"

tar -xvvf "${WORKSPACE}/${DISTRO}.raw" ||
    fail "Result tar failed to unpack"

rm "${WORKSPACE}/${DISTRO}.raw" ||
    fail "Failed to remove unnecessary file"

# Put the bits in place
"${kvm_scripts}/copy_to_final.sh" \
     "${DISTRO}" "${WORKSPACE}" "${SERIAL}" "${BTYPE}" "${TEST_BUILD}" "${SANDBOX_BUILD}" ||
    fail "Failed to place final files to destination"

# Copy the build properties into the workspace
cp ${BUILD_PROPERTIES} .
echo "ARCH=${ARCH_TYPE}" >> build_properties
