#!/bin/bash
fail() { [ $# -eq 0 ] || echo "$@"; exit 1; }
cleanup() {
    rm "${WORKSPACE}/*vhd"
}

ver=$(${kvm}/ubuntu-adj2version ${SUITE})

umask 022
set -x
echo "-------------------"
echo " Distro:  ${SUITE}"
echo " Serial:  ${SERIAL}"
echo " Version: ${ver}"
echo "-------------------"

trap cleanup EXIT

# Disk names
vhd="/srv/ec2-images/${SUITE}/${SERIAL}/azure/${SUITE}-server-cloudimg-amd64-disk1.vhd.bz2"
final_disk_name="Ubuntu-${ver}-amd64-server-${SERIAL}-en-us-30GB.vhd"
final_disk_loc="${WORKSPACE}/${final_disk_name}"

# Extract the build disk
bunzip2 -c "${vhd}" > "${final_disk_loc}" ||
    fail "Failed to extract the working disk"

# Write the manifest file
echo "Check summing image and writing manifest file..."
cat << EOF > "${WORKSPACE}/registration-manifest.txt"
<?xml version="1.0" encoding="UTF-8"?>
<PlatformImage>
<Name>${final_disk_name}</NAME>
<Checksum>$(sha1sum ${final_disk_loc} | awk '{print$1}')</Checksum>
<Version>${ver}</Version>
<Category>Canonical</Category>
<Label>Ubuntu Server ${ver} ${serial}</Label>
<ImageFamily>Ubuntu ${ver}</ImageFamily>
<PublishedDate>$(date +%Y-%m-%d)</PublishedDate>
<PrivacyUri>http://www.ubuntu.com/aboutus/privacypolicy</PrivacyUri>
<IconUri>http://design.ubuntu.com/wp-content/uploads/ubuntu-logo32.png<IconUri>
<ShowInGui>${RELEASE_GUI:-False}</ShowInGui>
<RecommendedVMSize>Medium</RecommendedVMSize>
<Description>Ubuntu Server ${ver} amd64 ${serial} Cloud Image</Description>
<Language>En-us</Language>
<EulaLink>http://www.ubuntu.com/project/about-ubuntu/licensing</EulaLink>
<SizeInGB>30</SizeInGB>
<OS>Linux</OS>
</PlatformImage>
EOF

# Now upload images
azure_cmd="/srv/builder/azure/cronrun azure vm disk upload -f -v ${final_disk_loc}"
prefix="http://"
postfix="blob.core.windows.net/platformimages/${final_disk_name}"

[ -e "${WORKSPACE}/keys" ] &&
    mv "${WORKSPACE}/keys" "${WORKSPACE}/keys.$(date +%Y%m%d)"

echo -e "${BLOB}" > ${WORKSPACE}/keys
count=0
while read location key
do
    count=$(expr $count + 1)
    ${azure_cmd} ${prefix}${location}.${postfix} ${key} | tee "${WORKSPACE}/PUB-${count}.log"
done < ${WORKSPACE}/keys

rm "${final_disk_loc}"
